EXPORTS
	__20TIoConsWriterAdaptorR21RIoConsoleWriteHandle @ 1 NONAME R3UNUSED ; TIoConsWriterAdaptor::TIoConsWriterAdaptor(RIoConsoleWriteHandle &)
	Contents__C12TConsoleLine @ 2 NONAME R3UNUSED ; TConsoleLine::Contents(void) const
	CursorBeginning__12TConsoleLine @ 3 NONAME R3UNUSED ; TConsoleLine::CursorBeginning(void)
	CursorEnd__12TConsoleLine @ 4 NONAME R3UNUSED ; TConsoleLine::CursorEnd(void)
	CursorLeft__12TConsoleLine @ 5 NONAME R3UNUSED ; TConsoleLine::CursorLeft(void)
	CursorNextWord__12TConsoleLine @ 6 NONAME R3UNUSED ; TConsoleLine::CursorNextWord(void)
	CursorPreviousWord__12TConsoleLine @ 7 NONAME R3UNUSED ; TConsoleLine::CursorPreviousWord(void)
	CursorRight__12TConsoleLine @ 8 NONAME R3UNUSED ; TConsoleLine::CursorRight(void)
	DeleteLeft__12TConsoleLine @ 9 NONAME R3UNUSED ; TConsoleLine::DeleteLeft(void)
	DeleteRight__12TConsoleLine @ 10 NONAME R3UNUSED ; TConsoleLine::DeleteRight(void)
	End__12TConsoleLine @ 11 NONAME R3UNUSED ; TConsoleLine::End(void)
	HandleKey__11CLineEditorUiUi @ 12 NONAME R3UNUSED ; CLineEditor::HandleKey(unsigned int, unsigned int)
	Insert__12TConsoleLineG5TChar @ 13 NONAME R3UNUSED ; TConsoleLine::Insert(TChar)
	NewL__11CLineEditorR3RFsR22MAbstractConsoleWriterR19MLineEditorObserverR14MLineCompleter @ 14 NONAME ABSENT ; CLineEditor::NewL(RFs &, MAbstractConsoleWriter &, MLineEditorObserver &, MLineCompleter &)
	NewL__11CLineEditorR3RFsR22MAbstractConsoleWriterR19MLineEditorObserverR14MLineCompleterRC7TDesC16 @ 15 NONAME ; CLineEditor::NewL(RFs &, MAbstractConsoleWriter &, MLineEditorObserver &, MLineCompleter &, TDesC16 const &)
	Overwrite__12TConsoleLineG5TChar @ 16 NONAME R3UNUSED ; TConsoleLine::Overwrite(TChar)
	PrintCompletionPossibilitiesL__12TConsoleLineRC7TDesC16 @ 17 NONAME R3UNUSED ; TConsoleLine::PrintCompletionPossibilitiesL(TDesC16 const &)
	Redraw__12TConsoleLine @ 18 NONAME R3UNUSED ; TConsoleLine::Redraw(void)
	ReinstatePromptAndUserInput__11CLineEditor @ 19 NONAME R3UNUSED ; CLineEditor::ReinstatePromptAndUserInput(void)
	RemovePromptAndUserInput__11CLineEditor @ 20 NONAME R3UNUSED ; CLineEditor::RemovePromptAndUserInput(void)
	Replace__12TConsoleLineRC7TDesC16 @ 21 NONAME R3UNUSED ; TConsoleLine::Replace(TDesC16 const &)
	Replace__12TConsoleLineiRC7TDesC16 @ 22 NONAME R3UNUSED ; TConsoleLine::Replace(int, TDesC16 const &)
	Start__11CLineEditorRC7TDesC16 @ 23 NONAME R3UNUSED ; CLineEditor::Start(TDesC16 const &)
	Start__11CLineEditorRC7TDesC16T1 @ 24 NONAME R3UNUSED ; CLineEditor::Start(TDesC16 const &, TDesC16 const &)
	Start__12TConsoleLineRC7TDesC16 @ 25 NONAME R3UNUSED ; TConsoleLine::Start(TDesC16 const &)
	Start__12TConsoleLineRC7TDesC16T1 @ 26 NONAME R3UNUSED ; TConsoleLine::Start(TDesC16 const &, TDesC16 const &)
	"_._11CLineEditor" @ 27 NONAME R3UNUSED ; CLineEditor::~CLineEditor(void)
	__12TConsoleLineR8RConsole @ 28 NONAME R3UNUSED ; TConsoleLine::TConsoleLine(RConsole &)
	__19TConsoleBaseAdaptorR12CConsoleBase @ 29 NONAME R3UNUSED ; TConsoleBaseAdaptor::TConsoleBaseAdaptor(CConsoleBase &)
	ContentsToCursor__C12TConsoleLine @ 30 NONAME R3UNUSED ; TConsoleLine::ContentsToCursor(void) const
	Redraw__11CLineEditor @ 31 NONAME R3UNUSED ; CLineEditor::Redraw(void)
	Abort__11CLineEditor @ 32 NONAME R3UNUSED ; CLineEditor::Abort(void)

